package com.yiqi.crm.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.crm.domain.WxReply;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;
import java.util.Map;

/**
 * 微信内容管理Mapper接口
 *
 * @author ruoyi
 * @date 2023-07-27
 */
@Mapper
public interface WxReplyMapper extends BaseMapper<WxReply>{
    /**
     * 查询微信内容管理
     *
     * @param replyId 微信内容管理主键
     * @return 微信内容管理
     */
    public WxReply selectWxReplyByReplyId(Long replyId);

    /**
     * 查询微信内容管理列表
     *
     * @param wxReply 微信内容管理
     * @return 微信内容管理集合
     */
    public List<WxReply> selectWxReplyList(WxReply wxReply);

    /**
     * 新增微信内容管理
     *
     * @param wxReply 微信内容管理
     * @return 结果
     */
    public int insertWxReply(WxReply wxReply);

    /**
     * 修改微信内容管理
     *
     * @param wxReply 微信内容管理
     * @return 结果
     */
    public int updateWxReply(WxReply wxReply);

    /**
     * 删除微信内容管理
     *
     * @param replyId 微信内容管理主键
     * @return 结果
     */
    public int deleteWxReplyByReplyId(Long replyId);

    /**
     * 批量删除微信内容管理
     *
     * @param replyIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWxReplyByReplyIds(Long[] replyIds);

    /**
     * 获取对应关键词信息
     *
     * @param param  条件
     * @return 结果
     */
    List<WxReply> getKeyWordsReplyList(Map<String, Object> param);

    /**
     * 查询微信内容管理
     *
     * @param replyType 微信内容管理主键
     * @return 微信内容管理
     */
    public List<WxReply> selectWxReplyByReplyType(String replyType);

    Integer countLookNumber(WxReply wxReply);
}

